@echo off
chcp 65001 >nul
title 座位分配系统 v1.0

:: 设置颜色
color 0F

echo.
echo ==========================================
echo         座位分配系统 v1.0
echo ==========================================
echo.
echo 正在检查运行环境...
echo.

:: 检查可执行文件是否存在
if not exist "座位分配系统.exe" (
    echo [错误] 未找到 座位分配系统.exe 文件
    echo.
    echo 请确保以下文件在同一目录下:
    echo - 座位分配系统.exe
    echo - 人员信息.xlsx
    echo - 座位信息.xlsx
    echo.
    pause
    exit /b 1
)

echo [成功] 程序文件检查通过

:: 检查数据文件
set "missing_files="

if not exist "人员信息.xlsx" (
    echo [错误] 缺少文件: 人员信息.xlsx
    set "missing_files=1"
) else (
    echo [成功] 人员信息.xlsx 存在
)

if not exist "座位信息.xlsx" (
    echo [错误] 缺少文件: 座位信息.xlsx
    set "missing_files=1"
) else (
    echo [成功] 座位信息.xlsx 存在
)

:: 如果有缺失文件，给出指导
if defined missing_files (
    echo.
    echo ==========================================
    echo           数据文件缺失提示
    echo ==========================================
    echo.
    echo 请按照以下步骤准备数据文件:
    echo.
    echo 1. 如果您有示例文件，请重命名:
    echo    - 人员信息_示例.xlsx → 人员信息.xlsx
    echo    - 座位信息_示例.xlsx → 座位信息.xlsx
    echo.
    echo 2. 数据文件格式要求:
    echo.
    echo    人员信息.xlsx 必需列:
    echo    - 姓名: 人员姓名
    echo    - 证件类型: 身份证/护照等
    echo    - 证件号: 证件号码  
    echo    - 手机号: 联系电话
    echo    - 备注: 连坐人数(留空=单独坐)
    echo.
    echo    座位信息.xlsx 必需列:
    echo    - 区域: 座位区域
    echo    - 楼层: 楼层信息
    echo    - 排号: 排号
    echo    - 座位号: 具体座位号
    echo.
    echo 3. 连坐规则:
    echo    - 单人: 备注列留空
    echo    - 多人: 第一人填写总人数，其他人留空
    echo    - 示例: 张三(备注:3)、李四(空)、王五(空)
    echo.
    pause
    exit /b 1
)

echo.
echo ==========================================
echo           开始运行程序
echo ==========================================
echo.
echo 所有检查通过，正在启动座位分配系统...
echo 请等待程序运行完成...
echo.

:: 运行程序并捕获错误
"座位分配系统.exe"
set "exit_code=%ERRORLEVEL%"

echo.
echo ==========================================
echo           运行结果
echo ==========================================
echo.

if %exit_code% equ 0 (
    echo [成功] 程序运行成功!
    echo.
    echo 输出文件说明:
    echo - 座位信息_最终分配.xlsx: 最终座位分配结果
    echo - 最终座位分配日志.xlsx: 详细分配记录
    echo - seat_allocation_log.txt: 运行日志文件
    echo.
    echo 您可以用Excel打开xlsx文件查看结果
) else (
    echo [错误] 程序运行出现错误 (错误代码: %exit_code%)
    echo.
    echo 可能的原因:
    echo 1. 数据文件格式不正确
    echo 2. 文件权限不足
    echo 3. 磁盘空间不足
    echo 4. 缺少必要的依赖
    echo.
    echo 请查看 seat_allocation_log.txt 获取详细错误信息
)

echo.
echo 按任意键退出...
pause >nul 